import os


# ===== BASE URL =====
BASE_URL: str = "https://www.amazon.in/"

# ===== SAVING PATHS =====
SAVED_DATA_DIR: str = "Artifacts"

# ===== SCRAPPER DIR =====
URL_DATA_DIR: str = "UrlData"
PRODUCT_DATA_DIR: str = "ProductData"

# ===== SCRAPPER FILES =====
URL_FILE_NAME: str = "urls.json"
PRODUCT_FILE_NAME: str = "products.json"








